@@ -41,6 +41,7 @@ app starts up. A good place to do this setup is in your project's settings.py.
 
 """
 
+import os
 from django.template import loader, loader_tags, NodeList, Template, TemplateDoesNotExist, TemplateSyntaxError
 from django.template.context import Context
 from django.utils.safestring import mark_safe
@@ -237,6 +238,21 @@ def ExtendsNode__render(self, context):
 
 def setup():
     "Monkeypunch!"
+
+    if 'DJANGO_SETTINGS_MODULE' not in os.environ:
+        return
+
+    try:
+        # Only use the caching template loader if we can import it; available in
+        # Django 1.2 and later
+        import django.template.loaders.cached
+        from django.conf import settings
+        settings.TEMPLATE_LOADERS = (('django.template.loaders.cached.Loader', settings.TEMPLATE_LOADERS),)
+        return
+    except ImportError:
+        # lets do it the old-fashioned way
+        pass
+
     loader.get_template.func_code = get_template.func_code
     loader.get_template.func_globals['_template_cache'] = {}
     Context.__init__ = Context__init
