@@ -72,7 +72,7 @@ class SanitizeTestsMeta(type):
 
             def tester(filepath):
                 def test(self):
-                    self.run_feedparser_test(filepath)
+                    self.run_feedparser(filepath)
                 test.__name__ = testname
                 return test
 
@@ -88,7 +88,7 @@ class SanitizeTestsMeta(type):
 
             def tester(given, expected):
                 def test(self):
-                    self.run_test(given, expected)
+                    self.runTest(given, expected)
                 test.__name__ = testname
                 return test
 
@@ -143,7 +143,7 @@ class SanitizeTests(unittest.TestCase):
         ),
     }
 
-    def run_test(self, given, expected):
+    def runTest(self, given, expected):
         # Build our testing template with the given HTML.
         context = Context({'testcode': given})
         built = self.template.render(context)
@@ -151,7 +151,7 @@ class SanitizeTests(unittest.TestCase):
         # Check that the result is sanitized.
         self.assertEquals(built, expected)
 
-    def run_feedparser_test(self, filepath):
+    def run_feedparser(self, filepath):
         # Read the file normally to find what we expect.
         testfile = file(filepath)
         for x in testfile.xreadlines():
@@ -167,7 +167,7 @@ class SanitizeTests(unittest.TestCase):
         testcode = ''.join([n.data for n in content.childNodes
                             if n.nodeType == Node.TEXT_NODE])
 
-        self.run_test(testcode, expected)
+        self.runTest(testcode, expected)
 
     # These feedparser tests are about sanitizing content when the HTML is
     # encoded differently in the XML, so don't bother doing them.
@@ -222,85 +222,3 @@ class OAuthTests(unittest.TestCase):
         }
         cb_url = '%s?%s' % ('http://test.example.com/', urlencode(params))
         self.assertCallback(cb_url, 'url with query encoded with urllib.urlencode encodes right')
-
-
-class CacheEncodingTests(unittest.TestCase):
-
-    def run_cache_encoding(self):
-        cache = DjangoHttplib2Cache(self.cache)
-
-        cache.set('hi', "plain string")
-        hi = cache.get('hi')
-        # Django's memcache backend upgrades everything to unicodes, so make
-        # sure we do the same for *every* backend, for compatibility.
-        self.assert_(isinstance(hi, unicode))
-        self.assertEqual(hi, u"plain string", 'plain string retrieves fine')
-
-        cache.set('hi', u"unicode string")
-        hi = cache.get('hi')
-        self.assert_(isinstance(hi, unicode))
-        self.assertEqual(hi, u"unicode string", 'unicode retrieves fine')
-
-        cache.set('hi', u'I\xc3\xb1t\xc3\xabrn\xc3\xa2ti\xc3\xb4n\xc3\xa0liz\xc3\xa6ti\xc3\xb8n')
-        hi = cache.get('hi')
-        self.assert_(isinstance(hi, unicode))
-        self.assertEqual(hi, u'I\xc3\xb1t\xc3\xabrn\xc3\xa2ti\xc3\xb4n\xc3\xa0liz\xc3\xa6ti\xc3\xb8n',
-            'i18n unicode retrieves fine')
-
-        cache.set('hi', 'I\xc3\x83\xc2\xb1t\xc3\x83\xc2\xabrn\xc3\x83\xc2\xa2ti\xc3\x83\xc2\xb4n\xc3\x83\xc2\xa0liz\xc3\x83\xc2\xa6ti\xc3\x83\xc2\xb8n')
-        hi = cache.get('hi')
-        self.assert_(isinstance(hi, unicode))
-        self.assertEqual(hi, u'I\xc3\xb1t\xc3\xabrn\xc3\xa2ti\xc3\xb4n\xc3\xa0liz\xc3\xa6ti\xc3\xb8n',
-            'utf-8 i18n string retrieves as unicode')
-
-        # Try storing this utf-8 encoding as a plain string; Django doesn't
-        # upgrade it right.
-        cache.set('hi', 'ma\xf1ana')
-        hi = cache.get('hi')
-        self.assert_(isinstance(hi, unicode), 'even bad utf-8 string comes out as a unicode')
-        self.assertEqual(hi, u'ma\ufffd', 'bad utf-8 string got smushed')
-
-
-class MemcacheEncodingTests(CacheEncodingTests):
-
-    def setUp(self):
-        # Replace the memcache module with a fake 
-        if 'memcache' in sys.modules:
-            self.original_memcache_module = sys.modules['memcache']
-        self.mock_mc = mox.MockAnything()
-        sys.modules['cmemcache'] = self.mock_mc
-        sys.modules['memcache'] = self.mock_mc
-
-        import django.core.cache.backends.memcached
-        django.core.cache.backends.memcached.memcache = self.mock_mc
-
-    def test_cache_encoding(self):
-
-        mock_cache = mox.MockAnything()
-        self.mock_mc.Client(['127.0.0.1:11211']).AndReturn(mock_cache)
-        mock_cache.set('httpcache_hi', 'plain string', 300)
-        mock_cache.get('httpcache_hi').AndReturn('plain string')
-        mock_cache.set('httpcache_hi', 'unicode string', 300)
-        mock_cache.get('httpcache_hi').AndReturn('unicode string')
-        mock_cache.set('httpcache_hi', 'I\xc3\x83\xc2\xb1t\xc3\x83\xc2\xabrn\xc3\x83\xc2\xa2ti\xc3\x83\xc2\xb4n\xc3\x83\xc2\xa0liz\xc3\x83\xc2\xa6ti\xc3\x83\xc2\xb8n', 300)
-        mock_cache.get('httpcache_hi').AndReturn('I\xc3\x83\xc2\xb1t\xc3\x83\xc2\xabrn\xc3\x83\xc2\xa2ti\xc3\x83\xc2\xb4n\xc3\x83\xc2\xa0liz\xc3\x83\xc2\xa6ti\xc3\x83\xc2\xb8n')
-        mock_cache.set('httpcache_hi', 'I\xc3\x83\xc2\xb1t\xc3\x83\xc2\xabrn\xc3\x83\xc2\xa2ti\xc3\x83\xc2\xb4n\xc3\x83\xc2\xa0liz\xc3\x83\xc2\xa6ti\xc3\x83\xc2\xb8n', 300)
-        mock_cache.get('httpcache_hi').AndReturn('I\xc3\x83\xc2\xb1t\xc3\x83\xc2\xabrn\xc3\x83\xc2\xa2ti\xc3\x83\xc2\xb4n\xc3\x83\xc2\xa0liz\xc3\x83\xc2\xa6ti\xc3\x83\xc2\xb8n')
-        # The bad string is fixed, then encoded to utf-8.
-        mock_cache.set('httpcache_hi', 'ma\xef\xbf\xbd', 300)
-        mock_cache.get('httpcache_hi').AndReturn('ma\xef\xbf\xbd')
-
-        mox.Replay(self.mock_mc)
-        mox.Replay(mock_cache)
-
-        self.cache = django.core.cache.get_cache('memcached://127.0.0.1:11211/')
-
-        self.run_cache_encoding()
-
-        mox.Verify(self.mock_mc)
-        mox.Verify(mock_cache)
-
-    def tearDown(self):
-        if hasattr(self, 'original_memcache_module'):
-            sys.modules['memcache'] = self.original_memcache_module
-            del self.original_memcache_module
